@@ -36,7 +36,7 @@ SPECIAL_SYMBOL_MAP = {
 ERROR_NAV_LIST = ['Copyright', 'ICP备', 'QQ空间', '上一篇', '下一篇', '专题专栏', '主题分类', '主题词：', '二维码', '互动交流', '人人网', '优质工程评审',
                   '使用帮助', '依申请公开', '信息公开', '信息公开制度', '信息公开年报', '信息公开指南', '信息发布', '免责声明', '党建专栏', '党建工作', '党组织概况',
                   '公示公告', '公网安备', '关闭窗口', '分享到', '分类：', '办事服务', '加入收藏', '区政府文件', '协会文件', '协会章程', '协会简介', '协会领导', '发布日期',
-                  '发布日期', '发布时间', '发布机构', '发文日期', '名称：', '基层政务公开标准化规范化', '备案序号', '字体', '字号', '安全人员培训', '市场信用评价', '当前位置',
+                  '发布日期', '发布时间', '发布机构', '发文日期', '名称：', '基层政务公开标准化规范化', '备案序号', '字体', '安全人员培训', '市场信用评价', '当前位置',
                   '您当前的位置', '您现在所在的位置', '您的位置', '意见征集', '成文日期', '手机阅读', '打印', '打印本页', '打印此页', '扫一扫', '收藏本站', '政务公开',
                   '政务服务', '政府信息公开', '政府信息公开制度', '政府信息公开年报+', '政府信息公开指南', '政府信息公开申请表', '政府公报', '政府动态', '政府网站工作报表',
                   '政策文件', '政策法规', '新浪微博', '新闻公告', '无障碍浏览', '机构概况', '机构职能', '机构设置', '来源:', '来源：', '标题', '法定主动公开内容',
